<?php

namespace Nest\Database\Exceptions\Configuration;

use Nest\Database\Exceptions\DatabaseException;
use Throwable;

/**
 * Thrown when database loading fails because of a missing required configuration.
 */
class MissingRequiredConfigurationValueException extends DatabaseException
{
	/**
	 * @param string $databaseIdentifier Database identifier.
	 * @param string $factoryClass Database factory class.
	 * @param string $configKey Missing configuration key.
	 * @param int $code [optional] The Exception code.
	 * @param null|Throwable $previous [optional] The previous throwable used for the exception chaining.
	 */
	public function __construct(public string $databaseIdentifier, public string $factoryClass, public string $configKey, int $code = 0, ?Throwable $previous = null)
	{
		parent::__construct("Cannot load database $this->databaseIdentifier: cannot find required configuration $this->configKey for factory $this->factoryClass.", $code, $previous);
	}
}
