<?php

namespace Nest\Database\Exceptions;

use Nest\Database\Transactions\Transaction;
use Throwable;

/**
 * Exception thrown when the altered transaction is not the current one.
 */
class NotCurrentTransactionException extends DatabaseException
{
	/**
	 * @param Transaction $currentTransaction The current transaction.
	 * @param Transaction $alteredTransaction The altered transaction.
	 * @param int $code [optional] The Exception code.
	 * @param null|Throwable $previous [optional] The previous throwable used for the exception chaining.
	 */
	public function __construct(public Transaction $currentTransaction, public Transaction $alteredTransaction, int $code = 0, ?Throwable $previous = null)
	{
		parent::__construct(
			"Only the current transaction (".$this->currentTransaction->getUuid().") can be altered. Cannot alter ".$this->alteredTransaction->getUuid().".",
			$code, $previous
		);
	}
}
