<?php

namespace Nest\Database\Migrations\Configuration;

/**
 * Migrations configurator.
 */
class MigrationsConfigurator extends MigrationsConfiguration
{
	private string $migrationsNamespace;
	private string $migrationsPath;
	private string $preparationsPath;
	private string $migrationsDatabase;
	private string $migrationsTable;

	/**
	 * @param string $migrationsNamespace Database migrations PHP namespace.
	 * @return $this
	 */
	public function setMigrationsNamespace(string $migrationsNamespace): static
	{
		$this->migrationsNamespace = $migrationsNamespace;
		return $this;
	}

	/**
	 * @inheritDoc
	 */
	#[\Override] public function getMigrationsNamespace(): string
	{
		return $this->migrationsNamespace;
	}

	/**
	 * @param string $migrationsPath Database migrations path.
	 * @return $this
	 */
	public function setMigrationsPath(string $migrationsPath): static
	{
		$this->migrationsPath = $migrationsPath;
		return $this;
	}

	/**
	 * @inheritDoc
	 */
	#[\Override] public function getMigrationsPath(): string
	{
		return $this->migrationsPath;
	}

	/**
	 * @param string $preparationsPath Database preparations path.
	 * @return $this
	 */
	public function setPreparationsPath(string $preparationsPath): static
	{
		$this->preparationsPath = $preparationsPath;
		return $this;
	}

	/**
	 * @inheritDoc
	 */
	#[\Override] public function getPreparationsPath(): string
	{
		return $this->preparationsPath ?? parent::getPreparationsPath();
	}

	/**
	 * Set database to use for migrations table.
	 * @param string $databaseIdentifier Database identifier.
	 * @return $this
	 */
	public function setMigrationsDatabase(string $databaseIdentifier): static
	{
		$this->migrationsDatabase = $databaseIdentifier;
		return $this;
	}

	/**
	 * @inheritDoc
	 */
	public function getMigrationsDatabase(): string
	{
		return $this->migrationsDatabase ?? parent::getMigrationsDatabase();
	}

	/**
	 * @param string $migrationsTable Done migrations table name.
	 * @return $this
	 */
	public function setMigrationsTable(string $migrationsTable): static
	{
		$this->migrationsTable = $migrationsTable;
		return $this;
	}

	/**
	 * @inheritDoc
	 */
	#[\Override] public function getMigrationsTable(): string
	{
		return $this->migrationsTable ?? parent::getMigrationsTable();
	}
}
