<?php

namespace Nest\Database\Query;

use Nest\Database\Database;
use Nest\Database\Query\Where\HasWhere;
use Nest\Database\Exceptions\Query\MissingConditionValueException;

/**
 * Builder of a DELETE query.
 */
class DeleteQuery
{
	use HasWhere;

	/**
	 * Create a new DELETE query.
	 * @param Database $database The database on which to execute the query.
	 * @param string $table Base table of the DELETE query.
	 */
	public function __construct(protected Database $database, protected string $table)
	{}

	/**
	 * Get the database on which to execute the query.
	 * @return Database
	 */
	public function getDatabase(): Database
	{
		return $this->database;
	}

	/**
	 * Execute DELETE query.
	 * @return void
	 * @throws MissingConditionValueException
	 */
	public function execute(): void
	{
		// Execute built query and return result.
		$this->database->getQueriesAdapter()->delete($this->table, $this->wheres);
	}
}
